@@ -3,6 +3,7 @@ from .study import Study
 from .series import Series
 from .instance import Instance
 from .job import Job
+import uuid
 
 # This class contains a set of Instances that represents the status of a study at a given time.
 # Its main use is to avoid this kind of situation:
@@ -15,16 +16,22 @@ from .job import Job
 
 class InstancesSet:
 
-    def __init__(self, api_client: 'OrthancApiClient'):
-        self._api_client = api_client
+    def __init__(self, api_client: 'OrthancApiClient', id: str = None):
+        self.api_client = api_client
+        if id is None:
+            id = uuid.uuid4().hex.upper()[:8]
+        self.id = id
         self._all_instances_ids = []
         self._by_series = {}
         self.study_id = None
 
+    def __str__(self):
+        return f"{self.id} - {len(self.series_ids)} series / {len(self.instances_ids)} instances"
+
     def add_series(self, series_id: str):
         self._add_series(
             series_id=series_id,
-            instances_ids=self._api_client.series.get_instances_ids(orthanc_id=series_id)
+            instances_ids=self.api_client.series.get_instances_ids(orthanc_id=series_id)
         )
 
     def _add_series(self, series_id: str, instances_ids: List[str]):
@@ -81,7 +88,7 @@ class InstancesSet:
         return instances_set
 
     def delete(self):
-        self._api_client.post(
+        self.api_client.post(
             endpoint=f"tools/bulk-delete",
             json= {
                 "Resources": self.instances_ids
@@ -104,7 +111,7 @@ class InstancesSet:
         if keep_tags is not None and len(keep_tags) > 0:
             query['Keep'] = keep_tags
 
-        r = self._api_client.post(
+        r = self.api_client.post(
             endpoint=f"tools/bulk-modify",
             json=query)
 
@@ -112,7 +119,7 @@ class InstancesSet:
             rjson = r.json()
 
             # create the modified set from the response
-            modified_set = InstancesSet(api_client=self._api_client)
+            modified_set = InstancesSet(api_client=self.api_client)
             modified_instances_ids = []
             modified_series_ids = []
             modified_studies_ids = []
@@ -132,7 +139,7 @@ class InstancesSet:
                 return None  # we had a problem since the number of instances has changed !!!
 
             for s in modified_series_ids:
-                series_all_instances_ids = set(self._api_client.series.get_instances_ids(orthanc_id=s))
+                series_all_instances_ids = set(self.api_client.series.get_instances_ids(orthanc_id=s))
 
                 # the series might contain some instances that do not come from our modification, ignore them !
                 series_instances_ids = list(series_all_instances_ids.intersection(set(modified_instances_ids)))
@@ -150,13 +157,13 @@ class InstancesSet:
     # this method returns the list of removed instances IDs
     def filter_instances(self, filter) -> List[str]:
         series_to_delete = []
-        filtered = InstancesSet(self._api_client)
+        filtered = InstancesSet(self.api_client)
         filtered.study_id = self.study_id
 
         for series_id, instances_ids in self._by_series.items():
             instances_to_delete = []
             for instance_id in instances_ids:
-                if not filter(self._api_client, instance_id):
+                if not filter(self.api_client, instance_id):
                     instances_to_delete.append(instance_id)
 
             for i in instances_to_delete:
@@ -177,4 +184,4 @@ class InstancesSet:
     # prototype: processor(api_client, instance_id)
     def process_instances(self, processor):
         for instance_id in self._all_instances_ids:
-            processor(self._api_client, instance_id)
+            processor(self.api_client, instance_id)
